import discord
from cpl_core.logging import LoggerABC
from cpl_discord.events import OnVoiceStateUpdateABC

from bot_core.helper.event_checks import EventChecks
from modules.base.service.event_service import EventService


class BaseOnVoiceStateUpdateEventScheduledEventBonus(OnVoiceStateUpdateABC):
    def __init__(
        self,
        logger: LoggerABC,
        events: EventService,
    ):
        OnVoiceStateUpdateABC.__init__(self)
        self._logger = logger
        self._events = events

        self._logger.info(__name__, f"Module {type(self)} loaded")

    @EventChecks.check_is_ready()
    async def on_voice_state_update(
        self,
        member: discord.Member,
        before: discord.VoiceState,
        after: discord.VoiceState,
    ):
        self._logger.debug(__name__, f"Module {type(self)} started")
        if member.bot or after.channel is None:
            self._logger.debug(__name__, f"Module {type(self)} stopped")
            return

        active_event = self._events.get_active_event_by_channel_id(after.channel.id)
        if active_event is None:
            self._logger.debug(__name__, f"Module {type(self)} stopped")
            return

        self._events.give_xp_for_event_participation(member, active_event)

        self._logger.debug(__name__, f"Module {type(self)} stopped")
